@@ -464,7 +464,8 @@ http_method_t http_method_d(char **ss, char const **nname)
   case 'O': if (MATCH(s, "OPTIONS")) code = http_method_options; break;
   case 'P': if (MATCH(s, "POST")) code = http_method_post;
             else
-            if (MATCH(s, "PUT")) code = http_method_put; break;
+            if (MATCH(s, "PUT")) code = http_method_put;
+            break;
   case 'T': if (MATCH(s, "TRACE")) code = http_method_trace; break;
   }
 
