@@ -42,6 +42,7 @@
 #include <string.h>
 #include <assert.h>
 
+#include <sofia-sip/su_string.h>
 #include <sofia-sip/msg_date.h>
 #include <sofia-sip/bnf.h>
 
@@ -181,7 +182,7 @@ int time_d(char const **ss,
 issize_t msg_date_d(char const **ss, msg_time_t *date)
 {
   char const *s = *ss;
-  char const *wkday;
+  //char const *wkday;
   char const *tz;
   unsigned long day, year, hour, min, sec;
   int mon;
@@ -189,7 +190,8 @@ issize_t msg_date_d(char const **ss, msg_time_t *date)
   if (!IS_TOKEN(*s) || !date)
     return -1;
 
-  wkday = s; skip_token(&s); if (*s == ',') s++;
+  //wkday = s; 
+  skip_token(&s); if (*s == ',') s++;
   while (IS_LWS(*s)) s++;
 
   if (is_digit(*s)) {
@@ -238,7 +240,7 @@ issize_t msg_date_d(char const **ss, msg_time_t *date)
     if (time_d(&s, &hour, &min, &sec) < 0) return -1;
     if (*s) {
       tz = s; skip_token(&s); skip_lws(&s);
-      if (strncasecmp(tz, "GMT", 3) && strncasecmp(tz, "UCT", 3))
+      if (!su_casenmatch(tz, "GMT", 3) && !su_casenmatch(tz, "UCT", 3))
 	return -1;
     }
   }
@@ -246,7 +248,8 @@ issize_t msg_date_d(char const **ss, msg_time_t *date)
     /* actime-date =
        wkday SP month SP ( 2DIGIT | ( SP 1DIGIT )) SP time SP 4DIGIT */
     mon = month_d(s); skip_token(&s);
-    if (mon < 0 || !IS_LWS(*s)) return -1; s++;
+    if (mon < 0 || !IS_LWS(*s)) return -1;
+    s++;
     while (IS_LWS(*s)) s++;
     if (!is_digit(*s)) return -1;
     day = *s++ - '0'; if (is_digit(*s)) day = 10 * day + *s++ - '0';
