@@ -60,8 +60,10 @@
 #include <sofia-sip/su_string.h>
 
 #ifndef HAVE_STRTOULL
+#if !((defined(WIN32) || defined(_WIN32)) && (_MSC_VER >= 1800))
 unsigned longlong strtoull(const char *, char **, int);
 #endif
+#endif
 
 /**@defgroup su_tag Tag Item Lists
  *
@@ -411,7 +413,7 @@ int tl_gets(tagi_t const lst[], tag_type_t tag, tag_value_t value, ...)
 #if !defined(NDEBUG)
     else if (tt->tt_class && tt->tt_class->tc_ref_set) {
       fprintf(stderr, "WARNING: tag %s::%s directly used by tl_gets()\n",
-	      tt->tt_ns, tt->tt_name);
+			  tt->tt_ns ? tt->tt_ns : "", tt->tt_name ? tt->tt_name : "");
       assert(tt->tt_class == ref_tag_class);
     }
 #endif
@@ -483,8 +485,9 @@ tagi_t *t_filter(tagi_t *dst,
     size_t d = 0;
 
     for (f = filter; f; f = t_next(f)) {
-      if (TAG_TYPE_OF(f)->tt_filter)
-	d += (size_t)TAG_TYPE_OF(f)->tt_filter(NULL, f, src, bb);
+      tag_type_t tt_f = TAG_TYPE_OF(f);
+      if (tt_f->tt_filter)
+	d += (size_t)tt_f->tt_filter(NULL, f, src, bb);
       else if (tt == f->t_tag) {
 	d += t_len(src);
 	*bb = (char *)*bb + t_xtra(src, (size_t)*bb);
